@@ -222,7 +222,7 @@ class ServiceDefinition:
 
 
 class EvaluationParametersDict(TypedDict):
-    """ Extremely similar to docker-compose """
+    """Extremely similar to docker-compose"""
 
     version: str
     services: Dict[str, ServiceDefinitionDict]
@@ -232,19 +232,19 @@ class EvaluationParametersDict(TypedDict):
 @dataclass
 class EvaluationParameters:
     """
-        You can specify these fields for the docker file:
+    You can specify these fields for the docker file:
 
-            version: '3'
+        version: '3'
 
-            services:
-                evaluator:
-                    image: imagename
-                    environment:
-                        var: var
-                solution: # For the solution container
-                    image: SUBMISSION_CONTAINER
-                    environment:
-                        var: var
+        services:
+            evaluator:
+                image: imagename
+                environment:
+                    var: var
+            solution: # For the solution container
+                image: SUBMISSION_CONTAINER
+                environment:
+                    var: var
 
     """
 
@@ -258,19 +258,21 @@ class EvaluationParameters:
     # noinspection PyArgumentList
     @classmethod
     @wrap_config_reader2
-    def from_yaml(cls, d: EvaluationParametersDict) -> "EvaluationParameters":
-
-        services_ = d.get("services")
+    def from_yaml(cls, d0: EvaluationParametersDict) -> "EvaluationParameters":
+        d = dict(d0)
+        services_ = d.pop("services")
         if not isinstance(services_, dict):
             msg = "Expected dict"
             raise ZValueError(msg, got=services_)
 
         if not services_:
             msg = "No services described."
-            raise ValueError(msg)
-
-        version = d.get("version", "3")
+            raise ZValueError(msg)
 
+        version = d.pop("version", "3")
+        if d:
+            msg = "Extra field in the configuration"
+            raise ZValueError(msg, d0=d0, extra=list(d))
         services = {}
         for k, v in services_.items():
             services[k] = ServiceDefinition.from_yaml(v)
@@ -476,16 +478,16 @@ class ChallengeTransitions:
     def get_next_steps(
         self, status: Dict[StepName, JobStatusString], step2age=None
     ) -> Tuple[bool, Optional[EvalStateString], List[StepName]]:
-        """ status is a dictionary from step name to status.
+        """status is a dictionary from step name to status.
 
-            It contains at the beginning
+        It contains at the beginning
 
-                START: success
+            START: success
 
-            Returns:
-                 bool (complete)
-                 optional status:  ['error', 'failed', 'success']
-                 a list of steps to activate next
+        Returns:
+             bool (complete)
+             optional status:  ['error', 'failed', 'success']
+             a list of steps to activate next
 
         """
         CS = ChallengesConstants
@@ -674,7 +676,11 @@ class Score:
                 raise InvalidChallengeDescription(msg)
 
             return Score(
-                name=name, description=description, order=order, discretization=discretization, short=short,
+                name=name,
+                description=description,
+                order=order,
+                discretization=discretization,
+                short=short,
             )
         except KeyError as e:
             msg = "Missing config %s" % e
@@ -781,10 +787,6 @@ class ChallengeDescription:
 
     def __post_init__(self):
 
-        # check_isinstance(self.date_open, datetime)
-        # check_isinstance(self.date_close, datetime)
-        # logger.info(f'received {self.date_open.tzinfo} {id(self.date_open)}   {self.date_close.tzinfo}'
-        #               f' {id(self.date_close)}  ')
         if self.date_open.tzinfo is None:
             raise ValueError(self.date_open)
         if self.date_close.tzinfo is None:
@@ -833,7 +835,9 @@ class ChallengeDescription:
 
         closure = data.pop("closure", [])
         dependencies_ = data.pop("dependencies", {})
-        dependencies = object_from_ipce(dependencies_, Dict[str, ChallengeDependency])
+        dependencies: Dict[ChallengeName, ChallengeDependency] = object_from_ipce(
+            dependencies_, Dict[ChallengeName, ChallengeDependency]
+        )
         ct = from_steps_transitions(list(Steps), transitions)
 
         assert date_open.tzinfo is not None and date_close.tzinfo is not None
@@ -924,7 +928,7 @@ def add_timezone(d: Union[str, datetime]) -> datetime:
 
 @dataclass(repr=False)
 class SubmissionDescription:
-    challenge_names: Optional[List[str]]
+    challenge_names: Optional[List[ChallengeName]]
     protocols: List[str]
     user_label: Optional[str]
     user_metadata: Dict[str, object]
@@ -973,6 +977,7 @@ class SubmissionDescription:
         description = data.pop("description", None)
         user_label = data.pop("user-label", None)
         user_metadata = data.pop("user-payload", None)
+        validation_challenge = data.pop("validation_challenge", None)
 
         return SubmissionDescription(
             challenge_names=challenges,
