@@ -11,10 +11,10 @@ from collections import namedtuple
 from contextlib import contextmanager
 from dataclasses import dataclass
 from pathlib import Path
-from typing import ContextManager, Dict, Optional
+from typing import ContextManager, Dict, Iterator, Optional
 
-from duckietown_challenges import ChallengesConstants
-from . import logger, ENV_CHALLENGE_STEP_NAME
+from .challenges_constants import ChallengesConstants
+from . import logger
 from .types import JobStatusString
 from .constants import (
     CHALLENGE_DESCRIPTION_DIR,
@@ -26,11 +26,13 @@ from .constants import (
     CHALLENGE_TMP_SUBDIR,
     DEFAULT_ROOT,
     ENV_CHALLENGE_NAME,
+    ENV_CHALLENGE_STEP_NAME,
 )
 from .exceptions import InvalidEnvironment, InvalidEvaluator, InvalidSubmission
 from .solution_interface import ChallengeInterfaceEvaluator, ChallengeInterfaceSolution
 from .utils import d8n_make_sure_dir_exists
 from .yaml_utils import read_yaml_file, write_yaml
+from .challenge_evaluator import ChallengeEvaluator
 
 
 @dataclass
@@ -170,14 +172,14 @@ class ChallengeInterfaceSolutionConcrete(ChallengeInterfaceSolution):
             raise InvalidEnvironment(str(e))
 
     def get_current_step(self):
-        """ Returns the current step. """
+        """Returns the current step."""
         try:
             return os.environ[ENV_CHALLENGE_STEP_NAME]
         except KeyError as e:
             raise InvalidEnvironment(str(e))
 
     def get_completed_steps(self):
-        """ Returns the previous steps as a list of string """
+        """Returns the previous steps as a list of string"""
         p = os.path.join(self.root, CHALLENGE_PREVIOUS_STEPS_DIR)
         if not os.path.exists(p):
             msg = "Directory not found %s" % p
@@ -186,7 +188,7 @@ class ChallengeInterfaceSolutionConcrete(ChallengeInterfaceSolution):
         return list(dirnames)
 
     def get_completed_step_solution_files(self, step_name):
-        """ Returns a list of names for the files completed in a previous step. """
+        """Returns a list of names for the files completed in a previous step."""
         if step_name not in self.get_completed_steps():
             msg = 'No step "%s".' % step_name
             raise KeyError(msg)
@@ -194,7 +196,7 @@ class ChallengeInterfaceSolutionConcrete(ChallengeInterfaceSolution):
         return get_completed_step_solution_files(self.root, step_name)
 
     def get_completed_step_solution_file(self, step_name, basename):
-        """ Returns a filename for one of the files completed in a previous step."""
+        """Returns a filename for one of the files completed in a previous step."""
         return get_completed_step_solution_file(self.root, step_name, basename)
 
 
@@ -234,7 +236,13 @@ def get_completed_step_solution_file(root, step_name, basename):
     #     msg = 'No file %r' % basename
     #     raise KeyError(msg)
 
-    fn = os.path.join(root, CHALLENGE_PREVIOUS_STEPS_DIR, step_name, CHALLENGE_SOLUTION_OUTPUT_DIR, basename,)
+    fn = os.path.join(
+        root,
+        CHALLENGE_PREVIOUS_STEPS_DIR,
+        step_name,
+        CHALLENGE_SOLUTION_OUTPUT_DIR,
+        basename,
+    )
     if not os.path.exists(fn):
         msg = "Cannot find %s; know %s" % (fn, available)
         raise KeyError(msg)
@@ -287,8 +295,9 @@ class ChallengeInterfaceEvaluatorConcrete(ChallengeInterfaceEvaluator):
     def internal_checks(self):
         root = self.root
         path = Path(root)
-        files = list(map(str, path.rglob("*.*")))
+        files = list(map(str, path.rglob("*")))
         logger.info(f"ChallengeInterfaceEvaluatorConcrete", root=root, files=files)
+        files = list(os.listdir(root))
         if not files:
             msg = "Invalid environment: challenges directory is empty. Not mounted correctly?"
             raise InvalidEnvironment(msg=msg, root=root, files=files)
@@ -427,14 +436,14 @@ class ChallengeInterfaceEvaluatorConcrete(ChallengeInterfaceEvaluator):
             raise InvalidEnvironment(str(e))
 
     def get_current_step(self):
-        """ Returns the current step. """
+        """Returns the current step."""
         try:
             return os.environ[ENV_CHALLENGE_STEP_NAME]
         except KeyError as e:
             raise InvalidEnvironment(str(e))
 
     def get_completed_steps(self):
-        """ Returns the previous steps as a list of string """
+        """Returns the previous steps as a list of string"""
         p = os.path.join(self.root, CHALLENGE_PREVIOUS_STEPS_DIR)
         if not os.path.exists(p):
             msg = f"Directory not found {p}"
@@ -443,7 +452,7 @@ class ChallengeInterfaceEvaluatorConcrete(ChallengeInterfaceEvaluator):
         return list(dirnames)
 
     def get_completed_step_evaluation_files(self, step_name):
-        """ Returns a list of names for the files completed in a previous step. """
+        """Returns a list of names for the files completed in a previous step."""
         if step_name not in self.get_completed_steps():
             msg = f"No step {step_name!r}"
             raise KeyError(msg)
@@ -455,7 +464,7 @@ class ChallengeInterfaceEvaluatorConcrete(ChallengeInterfaceEvaluator):
         # return list(os.listdir(d))
 
     def get_completed_step_evaluation_file(self, step_name, basename):
-        """ Returns a filename for one of the files completed in a previous step."""
+        """Returns a filename for one of the files completed in a previous step."""
         # if basename not in self.get_completed_step_evaluation_files(step_name):
         #     msg = 'No file %r' % basename
         #     raise KeyError(msg)
@@ -525,7 +534,7 @@ SPECIAL_INVALID_EVALUATOR = "invalid-evaluator"
 SPECIAL_INVALID_SUBMISSION = "invalid-submission"
 
 
-def wrap_evaluator(evaluator, root=DEFAULT_ROOT):
+def wrap_evaluator(evaluator: ChallengeEvaluator, root=DEFAULT_ROOT):
     from .col_logging import setup_logging_color
 
     setup_logging_color()
@@ -549,6 +558,7 @@ def wrap_evaluator(evaluator, root=DEFAULT_ROOT):
         try:
             evaluator.prepare(cie)
         except (BaseException, KeyboardInterrupt) as e:
+            logger.info(evaluator=evaluator)
             msg = "Preparation aborted"
             cie.set_challenge_parameters({SPECIAL_ABORT: msg})
             raise Exception(msg) from e
@@ -639,7 +649,7 @@ def wrap_scorer(evaluator, root=DEFAULT_ROOT):
 
 
 @contextmanager
-def scoring_context(root=DEFAULT_ROOT) -> ContextManager[ChallengeInterfaceEvaluator]:
+def scoring_context(root=DEFAULT_ROOT) -> Iterator[ChallengeInterfaceEvaluator]:
     logger.info("Environment variables", environment=dict(os.environ))
 
     from .col_logging import setup_logging_color
